@@ -117,7 +117,7 @@ class Database():
         for column in columns:
             sql += "{column} = %s".format(column=column)
             if columns.index(column) == len(columns) - 1:
-                sql += " WHERE id = {row_id}".format(row_id=row_id)
+                sql += ", updated_at = current_timestamp WHERE id = {row_id}".format(row_id=row_id)
             else:
                 sql += ", "
         
